.. include:: ../README.rst

.. rubric:: Documentation contents

.. toctree::
   :maxdepth: 2
   :numbered: 3

   why
   quick
   cli
   reference

.. toctree::
   :maxdepth: 1

   changelog
   contributing
